==> instagram_sync-1.0.0.tar.gz: instagram_sync/src/Entity/InstagramSync.php <==
<?php

namespace Drupal\instagram_sync\Entity;

use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityChangedTrait;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\instagram_sync\InstagramSyncInterface;

/**
 * Defines the instagram sync entity class.
 *
 * @ContentEntityType(
 *   id = "instagram_sync",
 *   label = @Translation("Instagram Sync"),
 *   label_collection = @Translation("Instagram Syncs"),
 *   label_singular = @Translation("instagram sync"),
 *   label_plural = @Translation("instagram syncs"),
 *   label_count = @PluralTranslation(
 *     singular = "@count instagram syncs",
 *     plural = "@count instagram syncs",
 *   ),
 *   handlers = {
 *     "list_builder" = "Drupal\instagram_sync\InstagramSyncListBuilder",
 *     "views_data" = "Drupal\views\EntityViewsData",
 *     "form" = {
 *       "add" = "Drupal\instagram_sync\Form\InstagramSyncForm",
 *       "edit" = "Drupal\instagram_sync\Form\InstagramSyncForm",
 *       "delete" = "Drupal\Core\Entity\ContentEntityDeleteForm",
 *     },
 *     "route_provider" = {
 *       "html" =
 *   "Drupal\instagram_sync\Routing\InstagramSyncHtmlRouteProvider",
 *     }
 *   },
 *   base_table = "instagram_sync",
 *   admin_permission = "administer instagram sync",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid",
 *   },
 *   links = {
 *     "collection" = "/admin/content/instagram-sync",
 *     "add-form" = "/instagram-sync/add",
 *     "canonical" = "/instagram-sync/{instagram_sync}",
 *     "edit-form" = "/instagram-sync/{instagram_sync}",
 *     "delete-form" = "/instagram-sync/{instagram_sync}/delete",
 *   },
 *   field_ui_base_route = "entity.instagram_sync.settings",
 * )
 */
class InstagramSync extends ContentEntityBase implements InstagramSyncInterface {

  use EntityChangedTrait;

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {

    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['label'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Label'))
      ->setRequired(TRUE)
      ->setSetting('max_length', 255)
      ->setDisplayOptions('form', [
        'type' => 'string_textfield',
        'weight' => -5,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'string',
        'weight' => -5,
      ])
      ->setDisplayConfigurable('view', TRUE);

    $fields['type'] = BaseFieldDefinition::create('list_string')
      ->setLabel(t('Type'))
      ->setDescription(t('The type of the entity.'))
      ->setSettings([
        'allowed_values' => [
          'carousel' => 'Carousel',
          'video' => 'Video',
          'image' => 'Image',
        ],
      ])
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'string',
        'weight' => -4,
      ])
      ->setDisplayOptions('form', [
        'type' => 'options_select',
        'weight' => -4,
      ])
      ->setRequired(TRUE)
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['instagram_sync_image'] = BaseFieldDefinition::create('image')
      ->setLabel(t('Instagram image'))
      ->setDescription(t('The image for the entity.'))
      ->setSettings([
        'file_directory' => 'instagram_sync/images/[date:custom:Y]-[date:custom:m]',
        'alt_field_required' => FALSE,
        'file_extensions' => 'png jpg jpeg',
        'max_filesize' => '16 MB',
      ])
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'default',
        'weight' => -4,
      ])
      ->setDisplayOptions('form', [
        'type' => 'image_image',
        'weight' => -4,
      ])
      ->setCardinality(BaseFieldDefinition::CARDINALITY_UNLIMITED)
      ->setRequired(TRUE)
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['instagram_sync_video_file'] = BaseFieldDefinition::create('file')
      ->setLabel(t('Instagram video file'))
      ->setDescription(t('Upload a video file.'))
      ->setSettings([
        'file_extensions' => 'mp4',
        'file_directory' => 'instagram_sync/videos/[date:custom:Y]-[date:custom:m]',
      ])
      ->setDisplayOptions('form', [
        'type' => 'file_generic',
        'weight' => 5,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['caption'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('Caption'))
      ->setDescription(t('Instagram post caption.'))
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'text_default',
      ])
      ->setDisplayOptions('form', [
        'type' => 'text_textarea',
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['status'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Status'))
      ->setDefaultValue(TRUE)
      ->setSetting('on_label', 'Enabled')
      ->setDisplayOptions('form', [
        'type' => 'boolean_checkbox',
        'settings' => [
          'display_label' => FALSE,
        ],
        'weight' => 0,
      ])
      ->setDisplayOptions('view', [
        'type' => 'boolean',
        'label' => 'above',
        'weight' => 0,
        'settings' => [
          'format' => 'enabled-disabled',
        ],
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['like_count'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Like count'))
      ->setDescription(t('An integer field representing like count.'))
      ->setSettings([
        'default_value' => 0,
        'min' => 0,
      ])
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'number_integer',
      ])
      ->setDisplayOptions('form', [
        'type' => 'number',
      ])
      ->setRequired(TRUE)
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['comments_count'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Comments count'))
      ->setDescription(t('An integer field representing comments count.'))
      ->setSettings([
        'default_value' => 0,
        'min' => 0,
      ])
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'number_integer',
      ])
      ->setDisplayOptions('form', [
        'type' => 'number',
      ])
      ->setRequired(TRUE)
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Authored on'))
      ->setDescription(t('The time that the instagram sync was created.'))
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'timestamp',
        'weight' => 20,
      ])
      ->setDisplayOptions('form', [
        'type' => 'datetime_timestamp',
        'weight' => 20,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['changed'] = BaseFieldDefinition::create('changed')
      ->setLabel(t('Changed'))
      ->setDescription(t('The time that the instagram sync was last edited.'))
      ->setReadOnly(TRUE);

    return $fields;
  }

}

==> instagram_sync-1.1.1.tar.gz: instagram_sync/src/Entity/InstagramSync.php <==
<?php

namespace Drupal\instagram_sync\Entity;

use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityChangedTrait;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\instagram_sync\InstagramSyncInterface;

/**
 * Defines the instagram sync entity class.
 *
 * @ContentEntityType(
 *   id = "instagram_sync",
 *   label = @Translation("Instagram Sync"),
 *   label_collection = @Translation("Instagram Syncs"),
 *   label_singular = @Translation("instagram sync"),
 *   label_plural = @Translation("instagram syncs"),
 *   label_count = @PluralTranslation(
 *     singular = "@count instagram syncs",
 *     plural = "@count instagram syncs",
 *   ),
 *   handlers = {
 *     "list_builder" = "Drupal\instagram_sync\InstagramSyncListBuilder",
 *     "views_data" = "Drupal\views\EntityViewsData",
 *     "form" = {
 *       "add" = "Drupal\instagram_sync\Form\InstagramSyncForm",
 *       "edit" = "Drupal\instagram_sync\Form\InstagramSyncForm",
 *       "delete" = "Drupal\Core\Entity\ContentEntityDeleteForm",
 *     },
 *     "route_provider" = {
 *       "html" =
 *   "Drupal\instagram_sync\Routing\InstagramSyncHtmlRouteProvider",
 *     }
 *   },
 *   base_table = "instagram_sync",
 *   admin_permission = "administer instagram sync",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid",
 *   },
 *   links = {
 *     "collection" = "/admin/content/instagram-sync",
 *     "add-form" = "/admin/content/instagram-sync/add",
 *     "canonical" = "/instagram-sync/{instagram_sync}",
 *     "edit-form" = "/admin/content/instagram-sync/{instagram_sync}",
 *     "delete-form" = "/admin/content/instagram-sync/{instagram_sync}/delete",
 *   },
 *   field_ui_base_route = "entity.instagram_sync.settings",
 * )
 */
class InstagramSync extends ContentEntityBase implements InstagramSyncInterface {

  use EntityChangedTrait;

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {

    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['label'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Label'))
      ->setRequired(TRUE)
      ->setSetting('max_length', 255)
      ->setDisplayOptions('form', [
        'type' => 'string_textfield',
        'weight' => -5,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'string',
        'weight' => -5,
      ])
      ->setDisplayConfigurable('view', TRUE);

    $fields['type'] = BaseFieldDefinition::create('list_string')
      ->setLabel(t('Type'))
      ->setDescription(t('The type of the entity.'))
      ->setSettings([
        'allowed_values' => [
          'carousel' => 'Carousel',
          'video' => 'Video',
          'image' => 'Image',
        ],
      ])
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'string',
        'weight' => -4,
      ])
      ->setDisplayOptions('form', [
        'type' => 'options_select',
        'weight' => -4,
      ])
      ->setRequired(TRUE)
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['instagram_sync_image'] = BaseFieldDefinition::create('image')
      ->setLabel(t('Instagram image'))
      ->setDescription(t('The image for the entity.'))
      ->setSettings([
        'file_directory' => 'instagram_sync/images/[date:custom:Y]-[date:custom:m]',
        'alt_field_required' => FALSE,
        'file_extensions' => 'png jpg jpeg',
        'max_filesize' => '16 MB',
      ])
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'default',
        'weight' => -4,
      ])
      ->setDisplayOptions('form', [
        'type' => 'image_image',
        'weight' => -4,
      ])
      ->setCardinality(BaseFieldDefinition::CARDINALITY_UNLIMITED)
      ->setRequired(TRUE)
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['instagram_sync_video_file'] = BaseFieldDefinition::create('file')
      ->setLabel(t('Instagram video file'))
      ->setDescription(t('Upload a video file.'))
      ->setSettings([
        'file_extensions' => 'mp4',
        'file_directory' => 'instagram_sync/videos/[date:custom:Y]-[date:custom:m]',
      ])
      ->setDisplayOptions('form', [
        'type' => 'file_generic',
        'weight' => 5,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['caption'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('Caption'))
      ->setDescription(t('Instagram post caption.'))
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'text_default',
      ])
      ->setDisplayOptions('form', [
        'type' => 'text_textarea',
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['status'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Status'))
      ->setDefaultValue(TRUE)
      ->setSetting('on_label', 'Enabled')
      ->setDisplayOptions('form', [
        'type' => 'boolean_checkbox',
        'settings' => [
          'display_label' => FALSE,
        ],
        'weight' => 0,
      ])
      ->setDisplayOptions('view', [
        'type' => 'boolean',
        'label' => 'above',
        'weight' => 0,
        'settings' => [
          'format' => 'enabled-disabled',
        ],
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['like_count'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Like count'))
      ->setDescription(t('An integer field representing like count.'))
      ->setSettings([
        'default_value' => 0,
        'min' => 0,
      ])
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'number_integer',
      ])
      ->setDisplayOptions('form', [
        'type' => 'number',
      ])
      ->setRequired(TRUE)
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['comments_count'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Comments count'))
      ->setDescription(t('An integer field representing comments count.'))
      ->setSettings([
        'default_value' => 0,
        'min' => 0,
      ])
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'number_integer',
      ])
      ->setDisplayOptions('form', [
        'type' => 'number',
      ])
      ->setRequired(TRUE)
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Authored on'))
      ->setDescription(t('The time that the instagram sync was created.'))
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'timestamp',
        'weight' => 20,
      ])
      ->setDisplayOptions('form', [
        'type' => 'datetime_timestamp',
        'weight' => 20,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['changed'] = BaseFieldDefinition::create('changed')
      ->setLabel(t('Changed'))
      ->setDescription(t('The time that the instagram sync was last edited.'))
      ->setReadOnly(TRUE);

    return $fields;
  }

}
